@@ -18,10 +18,10 @@
 #include "sysincludes.h"
 #include "msdos.h"
 
-const char *mversion="4.0.30";
+const char *mversion="4.0.34";
 
 /* Multiple releases on same day should be marked with (b), (cd), (d) after
  * date string below */
-const char *mdate = "June 17th, 2021";
+const char *mdate = "July 23th, 2021";
 
-const char *mformat_banner = "MTOO4030";
+const char *mformat_banner = "MTOO4034";
