@@ -20,7 +20,6 @@
 #ifndef SYSINCLUDES_H
 #define SYSINCLUDES_H
 
-#define _LARGEFILE64_SOURCE
 #define _GNU_SOURCE
 
 #include "config.h"
@@ -54,9 +53,9 @@
 
 
 /* On AIX, we have to prefer strings.h, as string.h lacks a prototype
- * for strcasecmp. On most other architectures, it's string.h which seems
- * to be more complete */
-#if (defined OS_aix && defined HAVE_STRINGS_H)
+ * for strcasecmp. On Solaris, string.h lacks a prototype for strncasecmp_l.
+ * On most other architectures, it's string.h which seems to be more complete */
+#if ((defined OS_aix || defined OS_solaris) && defined HAVE_STRINGS_H)
 # undef HAVE_STRING_H
 #endif
 
@@ -135,9 +134,6 @@ typedef void *caddr_t;
 /*                                                                     */
 /***********************************************************************/
 
-#define _LARGEFILE64_SOURCE
-#define _GNU_SOURCE
-
 #ifdef HAVE_ASSERT_H
 # include <assert.h>
 #endif
@@ -153,6 +149,10 @@ typedef void *caddr_t;
 # include <stdint.h>
 #endif
 
+#ifdef HAVE_STDARG_H
+# include <stdarg.h>
+#endif
+
 #if HAVE_STDBOOL_H
 # include <stdbool.h>
 #else
